@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( uninitialized once );
 
-our $VERSION = '1.843';
+our $VERSION = '1.868';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
@@ -26,17 +26,15 @@ $Carp::Internal{ (__PACKAGE__) }++;
 my ( $freeze, $thaw );
 
 BEGIN {
-   if ( ! defined $INC{'PDL.pm'} ) {
-      local $@; eval '
-         use Sereal::Encoder 3.015 qw( encode_sereal );
-         use Sereal::Decoder 3.015 qw( decode_sereal );
-      ';
+   if ( $] ge '5.008008' && ! $INC{'PDL.pm'} ) {
+      local $@;
+      eval 'use Sereal::Encoder 3.015; use Sereal::Decoder 3.015;';
       if ( ! $@ ) {
          my $encoder_ver = int( Sereal::Encoder->VERSION() );
          my $decoder_ver = int( Sereal::Decoder->VERSION() );
          if ( $encoder_ver - $decoder_ver == 0 ) {
-            $freeze = \&encode_sereal;
-            $thaw   = \&decode_sereal;
+            $freeze = \&Sereal::Encoder::encode_sereal;
+            $thaw   = \&Sereal::Decoder::decode_sereal;
          }
       }
    }
@@ -49,19 +47,18 @@ BEGIN {
 }
 
 use MCE::Util ();
-use bytes;
 
 my $is_MSWin32 = ( $^O eq 'MSWin32' ) ? 1 : 0;
-my $has_threads = $INC{'threads.pm'} ? 1 : 0;
-my $tid = $has_threads ? threads->tid() : 0;
+my $tid = $INC{'threads.pm'} ? threads->tid() : 0;
 
 sub new {
    my ( $class, %argv ) = @_;
    my $impl = defined( $argv{impl} ) ? ucfirst( lc $argv{impl} ) : 'Mutex';
 
-   $impl = 'Threads' if ( $^O eq 'MSWin32' && $impl eq 'Mutex' );
+   $impl = 'Threads' if ( $impl eq 'Mutex'   && $^O eq 'MSWin32' );
+   $impl = 'Mutex'   if ( $impl eq 'Threads' && $^O eq 'cygwin' );
 
-   eval "require MCE::Channel::$impl; 1" ||
+   eval "require MCE::Channel::$impl; 1;" ||
       Carp::croak("Could not load Channel implementation '$impl': $@");
 
    my $pkg = 'MCE::Channel::'.$impl;
@@ -71,16 +68,15 @@ sub new {
 }
 
 sub CLONE {
-   $tid = threads->tid if $has_threads;
+   $tid = threads->tid if $INC{'threads.pm'};
 }
 
 sub DESTROY {
-   my ( $pid, $self ) = ( $has_threads ? $$ .'.'. $tid : $$, @_ );
+   my ( $pid, $self ) = ( $tid ? $$ .'.'. $tid : $$, @_ );
 
    if ( $self->{'init_pid'} && $self->{'init_pid'} eq $pid ) {
-      MCE::Util::_destroy_socks( $self, qw(c_sock p_sock) );
-      delete $self->{c_mutex};
-      delete $self->{p_mutex};
+      MCE::Util::_destroy_socks($self, qw(c_sock c2_sock p_sock p2_sock));
+      delete($self->{c_mutex}), delete($self->{p_mutex});
    }
 
    return;
@@ -112,7 +108,7 @@ sub _read {
 }
 
 sub _pid {
-   $has_threads ? $$ .'.'. $tid : $$;
+   $tid ? $$ .'.'. $tid : $$;
 }
 
 1;
@@ -131,7 +127,7 @@ MCE::Channel - Queue-like and two-way communication capability
 
 =head1 VERSION
 
-This document describes MCE::Channel version 1.843
+This document describes MCE::Channel version 1.868
 
 =head1 SYNOPSIS
 
@@ -215,18 +211,21 @@ both ends of the C<channel> support many workers concurrently (with mp => 1).
 
 =head2 new ( impl => STRING, mp => BOOLEAN )
 
-This creates a new channel. Three implementations are provided C<Mutex> (default),
-C<Threads>, and C<Simple> indicating the locking mechanism to use C<MCE::Mutex>,
-C<threads::shared>, and no locking respectively.
+This creates a new channel. Three implementations are provided C<Mutex>,
+C<Threads>, and C<Simple> indicating the locking mechanism to use
+C<MCE::Mutex>, C<threads::shared>, and no locking respectively.
 
  $chnl = MCE::Channel->new();     # default: impl => 'Mutex', mp => 0
+                                  # default: impl => 'Threads' on Windows
 
-The C<Mutex> channel implementation supports processes and threads whereas the
-C<Threads> channel implementation is suited for threads only.
+The C<Mutex> implementation supports processes and threads whereas the
+C<Threads> implementation is suited for Windows and threads only.
 
  $chnl = MCE::Channel->new( impl => 'Mutex' );    # MCE::Mutex locking
  $chnl = MCE::Channel->new( impl => 'Threads' );  # threads::shared locking
 
+ # on Windows, silently becomes impl => 'Threads' when specifying 'Mutex'
+
 Set the C<mp> (m)any (p)roducers option to a true value if there will be two
 or more workers calling C<enqueue>, <send>, C<recv2>, or C<recv2_nb> on the
 left end of the channel. This is important to not incur a race condition.
@@ -234,6 +233,8 @@ left end of the channel. This is important to not incur a race condition.
  $chnl = MCE::Channel->new( impl => 'Mutex', mp => 1 );
  $chnl = MCE::Channel->new( impl => 'Threads', mp => 1 );
 
+ # on Windows, silently becomes impl => 'Threads' when specifying 'Mutex'
+
 The C<Simple> implementation is optimized for one producer and one consumer max.
 It omits locking for maximum performance. This implementation is preferred for
 parent to child communication not shared by another worker.
@@ -373,11 +374,13 @@ using L<threads::shared> for locking versus L<MCE::Mutex>.
  my $num_consumers = 10;
 
  sub consumer {
-    # receive items
     my $count = 0;
+
+    # receive items
     while ( my ($item1, $item2) = $queue->dequeue(2) ) {
        $count += 2;
     }
+
     # send result
     $queue->send2( threads->tid => $count );
  }
@@ -435,11 +438,13 @@ which is the default if omitted.
  my $num_consumers = 10;
 
  sub consumer {
-    # receive items
     my $count = 0;
+
+    # receive items
     while ( my ($item1, $item2) = $queue->dequeue(2) ) {
        $count += 2;
     }
+
     # send result
     $queue->send2( MCE::Child->pid => $count );
  }
@@ -465,7 +470,67 @@ which is the default if omitted.
  print $results{$_}, "\n" for keys %results;
  print "$total total\n\n";
 
-=head2 Example 3 - Many producers
+=head2 Example 3 - Consumer requests item
+
+Like the previous example, but have the manager process await a notification
+from the consumer before inserting into the queue. This allows the producer
+to end the channel early (i.e. exit loop).
+
+ use strict;
+ use warnings;
+
+ use MCE::Child;
+ use MCE::Channel;
+
+ my $queue = MCE::Channel->new( impl => 'Mutex' );
+ my $num_consumers = 10;
+
+ sub consumer {
+    # receive items
+    my $count = 0;
+
+    while () {
+       # Notify the manager process to send items. This allows the
+       # manager process to enqueue only when requested. The benefit
+       # is being able to end the channel immediately.
+
+       $queue->send2( MCE::Child->pid ); # channel is bi-directional
+
+       my ($item1, $item2) = $queue->dequeue(2);
+       last unless ( defined $item1 );   # channel ended
+
+       $count += 2;
+    }
+
+    # result
+    return ( MCE::Child->pid => $count );
+ }
+
+ MCE::Child->create('consumer') for 1 .. $num_consumers;
+
+ ## producer
+
+ for my $num (1 .. 40000) {
+    # Await worker notification before inserting (blocking).
+    my $consumer_pid = $queue->recv2;
+    $queue->enqueue($num, $num * 2);
+ }
+
+ $queue->end;
+
+ my %results;
+ my $total = 0;
+
+ for my $child ( MCE::Child->list ) {
+    my ($id, $count) = $child->join;
+    $results{$id} = $count;
+    $total += $count;
+ }
+
+ print $results{$_}, "\n" for keys %results;
+ print "$total total\n\n";
+
+=head2 Example 4 - Many producers
 
 Running with 2 or more producers requires setting the C<mp> option. Internally,
 this enables locking support for the left end of the channel. The C<mp> option
@@ -525,7 +590,7 @@ Here, using the MCE facility for gathering the final count.
 
  print "$total total\n\n";
 
-=head2 Example 4 - Request input
+=head2 Example 5 - Many channels
 
 This demonstration configures a channel per consumer. Plus, a common channel
 for consumers to request the next input item. The C<Simple> implementation is
@@ -648,9 +713,9 @@ Mario E. Roy, S<E<lt>marioeroy AT gmail DOT comE<gt>>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2019 by Mario E. Roy
+Copyright (C) 2019-2020 by Mario E. Roy
 
-MCE::Shared is released under the same license as Perl.
+MCE::Channel is released under the same license as Perl.
 
 See L<http://dev.perl.org/licenses/> for more information.
 
