@@ -14,7 +14,7 @@ package MCE::Core::Manager;
 use strict;
 use warnings;
 
-our $VERSION = '1.843';
+our $VERSION = '1.868';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
@@ -34,8 +34,6 @@ use constant {
       ? &POSIX::WNOHANG : ( $^O eq 'solaris' ) ? 64 : 1
 };
 
-use bytes;
-
 ###############################################################################
 ## ----------------------------------------------------------------------------
 ## Call on task_end after task completion.
@@ -61,6 +59,9 @@ sub _task_end {
          $_task_end->($self, $_task_id, $_task_name);
       }
    }
+   elsif (defined $self->{task_end}) {
+      $self->{task_end}->($self, 0, $self->{task_name});
+   }
 
    return;
 }
@@ -74,6 +75,35 @@ sub _task_end {
 ##
 ###############################################################################
 
+my %_sendto_fhs;
+
+sub _sendto_fhs_close {
+   for my $_p (keys %_sendto_fhs) {
+      close  $_sendto_fhs{$_p};
+      delete $_sendto_fhs{$_p};
+   }
+}
+
+sub _sendto_fhs_get {
+   my ($self, $_fd) = @_;
+
+   $_sendto_fhs{$_fd} || do {
+
+      $_sendto_fhs{$_fd} = IO::Handle->new();
+      $_sendto_fhs{$_fd}->fdopen($_fd, 'w')
+         or _croak "Cannot open file descriptor ($_fd): $!";
+
+      binmode $_sendto_fhs{$_fd};
+
+      if (!exists $self->{flush_file} || $self->{flush_file}) {
+         local $!;
+         $_sendto_fhs{$_fd}->autoflush(1)
+      }
+
+      $_sendto_fhs{$_fd};
+   };
+}
+
 sub _output_loop {
 
    my ( $self, $_input_data, $_input_glob, $_plugin_function,
@@ -82,15 +112,15 @@ sub _output_loop {
    @_ = ();
 
    my (
-      $_aborted, $_eof_flag, $_max_retries, $_syn_flag, %_sendto_fhs,
-      $_cb, $_chunk_id, $_chunk_size, $_fd, $_file, $_flush_file, $_wa,
+      $_aborted, $_eof_flag, $_max_retries, $_syn_flag, $_win32_ipc,
+      $_cb, $_chunk_id, $_chunk_size, $_file, $_size_completed, $_wa,
       @_is_c_ref, @_is_h_ref, @_is_q_ref, $_on_post_exit, $_on_post_run,
       $_has_user_tasks, $_sess_dir, $_task_id, $_user_error, $_user_output,
       $_input_size, $_offset_pos, $_single_dim, @_gather, $_cs_one_flag,
       $_exit_id, $_exit_pid, $_exit_status, $_exit_wid, $_len, $_sync_cnt,
       $_BSB_W_SOCK, $_BSB_R_SOCK, $_DAT_R_SOCK, $_DAU_R_SOCK, $_MCE_STDERR,
       $_I_FLG, $_O_FLG, $_I_SEP, $_O_SEP, $_RS, $_RS_FLG, $_MCE_STDOUT,
-      @_delay_wid, $_size_completed, $_win32_ipc
+      @_delay_wid
    );
 
    ## -------------------------------------------------------------------------
@@ -110,17 +140,13 @@ sub _output_loop {
          my @_ret = $_cb->(@_);
          my $_buf = $self->{freeze}(\@_ret);
 
-         return print {$_DAU_R_SOCK} length($_buf).'1'.$LF, $_buf;
+         return print {$_DAU_R_SOCK} length($_buf).$LF, $_buf;
       }
 
       my $_ret = $_cb->(@_);
-
-      return print {$_DAU_R_SOCK} length($_ret).'0'.$LF, $_ret
-         if ( !looks_like_number $_ret && !ref $_ret && defined $_ret );
-
       my $_buf = $self->{freeze}([ $_ret ]);
 
-      return print {$_DAU_R_SOCK} length($_buf).'1'.$LF, $_buf;
+      return print {$_DAU_R_SOCK} length($_buf).$LF, $_buf;
    };
 
    ## -------------------------------------------------------------------------
@@ -154,7 +180,7 @@ sub _output_loop {
             }
          }
 
-         _task_end($self, $_task_id) unless ($_total_running);
+         _task_end($self, $_task_id) unless $_total_running;
 
          return;
       },
@@ -206,6 +232,8 @@ sub _output_loop {
 
          ## Reap child/thread. Note: Win32 uses negative PIDs.
 
+         local ($!, $?);
+
          if ($_exit_pid =~ /^PID_(-?\d+)/) {
             my $_pid = $1; my $_list = $self->{_pids};
             for my $i (0 .. @{ $_list }) {
@@ -220,7 +248,7 @@ sub _output_loop {
             my $_tid = $1; my $_list = $self->{_tids};
             for my $i (0 .. @{ $_list }) {
                if ($_list->[$i] && $_list->[$i] == $_tid) {
-                  $self->{_thrs}->[$i]->join();
+                  eval { $self->{_thrs}->[$i]->join() };
                   $self->{_thrs}->[$i] = undef;
                   $self->{_tids}->[$i] = undef;
                   last;
@@ -235,13 +263,13 @@ sub _output_loop {
             $self->{_exited_wid} = $_exit_wid;
 
             if (length($_retry_buf)) {
-               $self->{_retry} = $self->{thaw}($_retry_buf);
-               my $_retry_cnt  = $_max_retries - $self->{_retry}[2] - 1;
+               $self->{_retry}     = $self->{thaw}($_retry_buf);
+               $self->{_retry_cnt} = $_max_retries - $self->{_retry}[2] - 1;
 
                $_on_post_exit->($self, {
                   wid => $_exit_wid, pid => $_exit_pid, status => $_exit_status,
                   msg => $_exit_msg, id  => $_exit_id
-               }, $_retry_cnt);
+               }, $self->{_retry_cnt});
 
                delete $self->{_retry};
             }
@@ -261,7 +289,7 @@ sub _output_loop {
             };
          }
 
-         _task_end($self, $_task_id) unless ($_total_running);
+         _task_end($self, $_task_id) unless $_total_running;
 
          return;
       },
@@ -279,7 +307,7 @@ sub _output_loop {
          }
 
          if ($_single_dim && $_cs_one_flag) {
-            $_buf = $_input_data->[$_offset_pos];
+            $_buf = $self->{freeze}( [ $_input_data->[$_offset_pos] ] );
          }
          else {
             if ($_offset_pos + $_chunk_size - 1 < $_input_size) {
@@ -320,13 +348,15 @@ sub _output_loop {
 
             if ($_chunk_size <= MAX_RECS_SIZE) {
                if ($_chunk_size == 1) {
-                  $_buf = <$_input_glob>;
+                  $_buf .= $_input_glob->can('getline')
+                     ? $_input_glob->getline : <$_input_glob>;
                   $_eof_flag = 1 unless (length $_buf);
                }
                else {
                   my $_last_len = 0;
                   for (1 .. $_chunk_size) {
-                     $_buf .= <$_input_glob>;
+                     $_buf .= $_input_glob->can('getline')
+                        ? $_input_glob->getline : <$_input_glob>;
                      $_len  = length $_buf;
                      if ($_len == $_last_len) {
                         $_eof_flag = 1;
@@ -337,12 +367,21 @@ sub _output_loop {
                }
             }
             else {
-               if (read($_input_glob, $_buf, $_chunk_size) == $_chunk_size) {
-                  $_buf .= <$_input_glob>;
-                  $_eof_flag = 1 if (length $_buf == $_chunk_size);
+               if ($_input_glob->can('getline') && $_input_glob->can('read')) {
+                  if ($_input_glob->read($_buf, $_chunk_size) == $_chunk_size) {
+                     $_buf .= $_input_glob->getline;
+                     $_eof_flag = 1 if (length $_buf == $_chunk_size);
+                  } else {
+                     $_eof_flag = 1;
+                  }
                }
                else {
-                  $_eof_flag = 1;
+                  if (read($_input_glob, $_buf, $_chunk_size) == $_chunk_size) {
+                     $_buf .= <$_input_glob>;
+                     $_eof_flag = 1 if (length $_buf == $_chunk_size);
+                  } else {
+                     $_eof_flag = 1;
+                  }
                }
             }
          }
@@ -350,8 +389,10 @@ sub _output_loop {
          $_len = length $_buf; local $\ = undef if (defined $\);
 
          if ($_len) {
-            print {$_DAU_R_SOCK} $_len.$LF . (++$_chunk_id).$LF, $_buf;
-         } else {
+            my $_tmp = $self->{freeze}(\$_buf);
+            print {$_DAU_R_SOCK} length($_tmp).$LF . (++$_chunk_id).$LF, $_tmp;
+         }
+         else {
             print {$_DAU_R_SOCK} '0'.$LF;
          }
 
@@ -400,16 +441,10 @@ sub _output_loop {
 
          my @_ret_a = $_input_data->($_chunk_size);
 
-         if (scalar @_ret_a > 1 || ref $_ret_a[0]) {
+         if (@_ret_a > 1 || defined $_ret_a[0]) {
             $_buf = $self->{freeze}([ @_ret_a ]);
             $_len = length $_buf; local $\ = undef if (defined $\);
-            print {$_DAU_R_SOCK} $_len.'1'.$LF . (++$_chunk_id).$LF, $_buf;
-
-            return;
-         }
-         elsif (defined $_ret_a[0]) {
-            $_len = length $_ret_a[0]; local $\ = undef if (defined $\);
-            print {$_DAU_R_SOCK} $_len.'0'.$LF . (++$_chunk_id).$LF, $_ret_a[0];
+            print {$_DAU_R_SOCK} $_len.$LF . (++$_chunk_id).$LF, $_buf;
 
             return;
          }
@@ -423,25 +458,17 @@ sub _output_loop {
 
       ## ----------------------------------------------------------------------
 
-      OUTPUT_A_CBK.$LF => sub {                   # Callback w/ multiple args
-         chomp($_wa  = <$_DAU_R_SOCK>),
-         chomp($_cb  = <$_DAU_R_SOCK>),
-         chomp($_len = <$_DAU_R_SOCK>);
-
-         read $_DAU_R_SOCK, my($_buf), $_len;
-         my $_data_ref = $self->{thaw}($_buf); undef $_buf;
-
-         return $_cb_reply->(@{ $_data_ref });
-      },
-
-      OUTPUT_S_CBK.$LF => sub {                   # Callback w/ 1 scalar arg
+      OUTPUT_A_CBK.$LF => sub {                   # Callback w/ args
          chomp($_wa  = <$_DAU_R_SOCK>),
          chomp($_cb  = <$_DAU_R_SOCK>),
          chomp($_len = <$_DAU_R_SOCK>);
 
          read $_DAU_R_SOCK, my($_buf), $_len;
 
-         return $_cb_reply->($_buf);
+         my $_aref = $self->{thaw}($_buf);
+         undef $_buf;
+
+         return $_cb_reply->(@{ $_aref });
       },
 
       OUTPUT_N_CBK.$LF => sub {                   # Callback w/ no args
@@ -451,9 +478,7 @@ sub _output_loop {
          return $_cb_reply->();
       },
 
-      ## ----------------------------------------------------------------------
-
-      OUTPUT_A_GTR.$LF => sub {                   # Gather array/ref
+      OUTPUT_A_GTR.$LF => sub {                   # Gather data
          chomp($_task_id = <$_DAU_R_SOCK>),
          chomp($_len     = <$_DAU_R_SOCK>);
 
@@ -481,39 +506,19 @@ sub _output_loop {
          return;
       },
 
-      OUTPUT_S_GTR.$LF => sub {                   # Gather scalar
-         local $_;
-
-         chomp($_task_id = <$_DAU_R_SOCK>),
-         chomp($_len     = <$_DAU_R_SOCK>);
-
-         read $_DAU_R_SOCK, $_, $_len if ($_len >= 0);
-
-         if ($_is_c_ref[$_task_id]) {
-            $_gather[$_task_id]->($_);
-         }
-         elsif ($_is_h_ref[$_task_id]) {
-            $_gather[$_task_id]->{$_} = undef;
-         }
-         elsif ($_is_q_ref[$_task_id]) {
-            $_gather[$_task_id]->enqueue($_);
-         }
-         else {
-            push @{ $_gather[$_task_id] }, $_;
-         }
-
-         return;
-      },
-
       ## ----------------------------------------------------------------------
 
       OUTPUT_O_SND.$LF => sub {                   # Send >> STDOUT
          chomp($_len = <$_DAU_R_SOCK>);
+
          read $_DAU_R_SOCK, my($_buf), $_len;
+         $_buf = ${ $self->{thaw}($_buf) };
 
          if (defined $_user_output) {
             $_user_output->($_buf);
-         } else {
+         }
+         else {
+            use bytes;
             print {$_MCE_STDOUT} $_buf;
          }
 
@@ -522,11 +527,15 @@ sub _output_loop {
 
       OUTPUT_E_SND.$LF => sub {                   # Send >> STDERR
          chomp($_len = <$_DAU_R_SOCK>);
+
          read $_DAU_R_SOCK, my($_buf), $_len;
+         $_buf = ${ $self->{thaw}($_buf) };
 
          if (defined $_user_error) {
             $_user_error->($_buf);
-         } else {
+         }
+         else {
+            use bytes;
             print {$_MCE_STDERR} $_buf;
          }
 
@@ -536,25 +545,29 @@ sub _output_loop {
       OUTPUT_F_SND.$LF => sub {                   # Send >> File
          my ($_buf, $_OUT_FILE);
 
-         chomp($_file = <$_DAU_R_SOCK>),
-         chomp($_len  = <$_DAU_R_SOCK>);
-
+         chomp($_len = <$_DAU_R_SOCK>);
          read $_DAU_R_SOCK, $_buf, $_len;
 
+         $_buf  = $self->{thaw}($_buf);
+         $_file = $_buf->[0];
+
          unless (exists $_sendto_fhs{$_file}) {
-            open $_sendto_fhs{$_file}, '>>', $_file
+            open $_sendto_fhs{$_file}, ">>", "$_file"
                or _croak "Cannot open file for writing ($_file): $!";
 
             binmode $_sendto_fhs{$_file};
 
-            if ($_flush_file) {
+            if (!exists $self->{flush_file} || $self->{flush_file}) {
                local $!;
                $_sendto_fhs{$_file}->autoflush(1);
             }
          }
 
-         $_OUT_FILE = $_sendto_fhs{$_file};
-         print {$_OUT_FILE} $_buf;
+         {
+            use bytes;
+            $_OUT_FILE = $_sendto_fhs{$_file};
+            print {$_OUT_FILE} $_buf->[1];
+         }
 
          return;
       },
@@ -562,27 +575,17 @@ sub _output_loop {
       OUTPUT_D_SND.$LF => sub {                   # Send >> File descriptor
          my ($_buf, $_OUT_FILE);
 
-         chomp($_fd  = <$_DAU_R_SOCK>),
          chomp($_len = <$_DAU_R_SOCK>);
-
          read $_DAU_R_SOCK, $_buf, $_len;
 
-         unless (exists $_sendto_fhs{$_fd}) {
-            $_sendto_fhs{$_fd} = IO::Handle->new();
-            $_sendto_fhs{$_fd}->fdopen($_fd, 'w')
-               or _croak "Cannot open file descriptor ($_fd): $!";
+         $_buf = $self->{thaw}($_buf);
 
-            binmode $_sendto_fhs{$_fd};
-
-            if ($_flush_file) {
-               local $!;
-               $_sendto_fhs{$_fd}->autoflush(1);
-            }
+         {
+            use bytes;
+            $_OUT_FILE = _sendto_fhs_get($self, $_buf->[0]);
+            print {$_OUT_FILE} $_buf->[1];
          }
 
-         $_OUT_FILE = $_sendto_fhs{$_fd};
-         print {$_OUT_FILE} $_buf;
-
          return;
       },
 
@@ -629,6 +632,15 @@ sub _output_loop {
          return;
       },
 
+      OUTPUT_C_NFY.$LF => sub {                   # Chunk ID notification
+         chomp($_len = <$_DAU_R_SOCK>);
+
+         my ($_pid, $_chunk_id) = split /:/, $_len;
+         $self->{_pids_c}{$_pid} = $_chunk_id;
+
+         return;
+      },
+
       OUTPUT_P_NFY.$LF => sub {                   # Progress notification
          chomp($_len = <$_DAU_R_SOCK>);
 
@@ -674,12 +686,12 @@ sub _output_loop {
             my $_app_st = $_interval->{_time} + ($_delay / $_nodes * $_id);
             my $_wrk_st = ($_delay_wid[$_task_id] - 1) * $_delay + $_app_st;
 
-            $_delay = $_wrk_st - time;
+            $_delay = $_wrk_st - MCE::Util::_time();
 
             if ($_delay < 0.0 && $_app_tb) {
                my $_count = int($_delay * -1 / $_app_tb + 0.5) + 1;
                $_delay += $_app_tb * $_count;
-               $_interval->{_time} = time if ($_count > 2e9);
+               $_interval->{_time} = MCE::Util::_time() if ($_count > 2e9);
             }
 
             ($_delay > 0.0)
@@ -703,26 +715,35 @@ sub _output_loop {
    $_has_user_tasks = (defined $self->{user_tasks}) ? 1 : 0;
    $_cs_one_flag = ($self->{chunk_size} == 1) ? 1 : 0;
 
-   $_max_retries  = $self->{max_retries} || 0;
+   $_max_retries  = $self->{max_retries};
    $_on_post_exit = $self->{on_post_exit};
    $_on_post_run  = $self->{on_post_run};
    $_chunk_size   = $self->{chunk_size};
-   $_flush_file   = $self->{flush_file};
    $_user_output  = $self->{user_output};
    $_user_error   = $self->{user_error};
    $_single_dim   = $self->{_single_dim};
    $_sess_dir     = $self->{_sess_dir};
 
-   if ($_max_retries && !$_on_post_exit) {
+   if (defined $_max_retries && !$_on_post_exit) {
       $_on_post_exit = sub {
          my ($self, $_e, $_retry_cnt) = @_;
-         my ($_cnt, $_msg) = ($_retry_cnt + 1, "Error: chunk $_e->{id} failed");
 
-         ($_retry_cnt < $_max_retries)
-            ? print {*STDERR} "$_msg, retrying chunk attempt # ${_cnt}\n"
-            : print {*STDERR} "$_msg\n";
+         if ($_e->{id}) {
+            my $_cnt = $_retry_cnt + 1;
+            my $_msg = "Error: chunk $_e->{id} failed";
 
-         $self->restart_worker;
+            if (defined $self->{init_relay}) {
+               print {*STDERR} "$_msg, retrying chunk attempt # $_cnt\n"
+                  if ($_retry_cnt < $_max_retries);
+            }
+            else {
+               ($_retry_cnt < $_max_retries)
+                  ? print {*STDERR} "$_msg, retrying chunk attempt # $_cnt\n"
+                  : print {*STDERR} "$_msg\n";
+            }
+
+            $self->restart_worker;
+         }
       };
    }
 
@@ -776,7 +797,6 @@ sub _output_loop {
    }
    else {
       $_MCE_STDOUT = \*STDOUT;
-      binmode $_MCE_STDOUT;
    }
 
    if (defined $self->{stderr_file}) {
@@ -786,15 +806,18 @@ sub _output_loop {
    }
    else {
       $_MCE_STDERR = \*STDERR;
-      binmode $_MCE_STDERR;
    }
 
-   ## Autoflush STDERR-STDOUT handles if requested.
+   ## Autoflush STDERR-STDOUT handles if not specified or requested.
 
    {
       local $!;
-      $_MCE_STDERR->autoflush(1) if $self->{flush_stderr};
-      $_MCE_STDOUT->autoflush(1) if $self->{flush_stdout};
+
+      $_MCE_STDERR->autoflush(1)
+         if ( !exists $self->{flush_stderr} || $self->{flush_stderr} );
+
+      $_MCE_STDOUT->autoflush(1)
+         if ( !exists $self->{flush_stdout} || $self->{flush_stdout} );
    }
 
    ## -------------------------------------------------------------------------
@@ -806,6 +829,7 @@ sub _output_loop {
 
    $_win32_ipc = (
       $ENV{'PERL_MCE_IPC'} eq 'win32' ||
+      defined($self->{max_retries}) ||
       $INC{'MCE/Child.pm'} ||
       $INC{'MCE/Hobo.pm'}
    );
@@ -837,35 +861,95 @@ sub _output_loop {
       my ($_list, $_timeout) = ($self->{_pids}, $self->{loop_timeout});
       my ($_DAT_W_SOCK, $_pid) = ($self->{_dat_w_sock}->[0]);
 
+      $self->{_pids_c} = {};  # Chunk ID notification
+
       $_timeout = 5 if $_timeout < 5;
 
       local $SIG{ALRM} = sub {
-         alarm 0;
+         alarm 0; local ($!, $?);
+
          for my $i (0 .. @{ $_list }) {
             if ($_pid = $_list->[$i]) {
                if (waitpid($_pid, _WNOHANG)) {
+
+                  $_list->[$i] = undef;
+
+                  if ($? > abs($self->{_wrk_status})) {
+                     $self->{_wrk_status} = $?;
+                  }
+
+                  my $_task_id = $self->{_pids_t}{$_pid};
+                  my $_wid     = $self->{_pids_w}{$_pid};
+
                   $self->{_total_exited}  += 1;
                   $self->{_total_running} -= 1;
                   $self->{_total_workers} -= 1;
-                  $_list->[$i] = undef;
+
+                  if ($_has_user_tasks && $_task_id >= 0) {
+                     $self->{_task}->[$_task_id]->{_total_running} -= 1;
+                     $self->{_task}->[$_task_id]->{_total_workers} -= 1;
+                  }
+
+                  my $_total_running = ($_has_user_tasks)
+                     ? $self->{_task}->[$_task_id]->{_total_running}
+                     : $self->{_total_running};
+
+                  if ($_task_id == 0 && defined $_syn_flag && $_sync_cnt) {
+                     if ($_sync_cnt == $_total_running) {
+                        for my $_i (1 .. $_total_running) {
+                           syswrite($_BSB_W_SOCK, $LF);
+                        }
+                        undef $_syn_flag;
+                     }
+                  }
+
+                  _task_end($self, $_task_id) unless $_total_running;
+
+                  if (my $_cid = $self->{_pids_c}{$_pid}) {
+                     warn "Error: process $_pid has ended prematurely\n",
+                          "Error: chunk $_cid failed\n";
+
+                     if ($_cid > $self->{_relayed}) {
+                        local $SIG{CHLD} = 'IGNORE';
+                        my $_pid = fork;
+
+                        if (defined $_pid && $_pid == 0) {
+                           delete $self->{max_retries};
+
+                           $self->{_chunk_id} = $_cid;
+                           $self->{_task_id}  = $_task_id;
+                           $self->{_wid}      = $_wid;
+
+                           eval 'MCE::relay';
+
+                           CORE::kill('KILL', $$);
+                           CORE::exit(0);
+                        }
+                     }
+                  }
+
+                  delete $self->{_pids_c}{$_pid};
+                  delete $self->{_pids_t}{$_pid};
+                  delete $self->{_pids_w}{$_pid};
                }
             }
          }
+
          print {$_DAT_W_SOCK} 'NOOP'.$LF . '0'.$LF;
       };
 
       while ( $self->{_total_running} ) {
-         alarm $_timeout;
-         $_func = <$_DAT_R_SOCK>;
+         alarm $_timeout; $_func = <$_DAT_R_SOCK>; alarm 0;
          $_DAU_R_SOCK = $_channels->[ <$_DAT_R_SOCK> ];
 
-         alarm 0;
          if (exists $_core_output_function{$_func}) {
             $_core_output_function{$_func}();
          } elsif (exists $_plugin_function->{$_func}) {
             $_plugin_function->{$_func}();
          }
       }
+
+      delete $self->{_pids_c};
    }
 
    ## Wait on requests *without* timeout capability.
@@ -884,6 +968,8 @@ sub _output_loop {
             $_plugin_function->{$_func}();
          }
       }
+
+      MCE::Util::_nonblocking($_DAT_R_SOCK, 0) if $_win32_ipc;
    }
    else {
       while ($self->{_total_running}) {
@@ -911,11 +997,7 @@ sub _output_loop {
 
    ## Close opened sendto file handles.
 
-   for my $_p (keys %_sendto_fhs) {
-      close  $_sendto_fhs{$_p};
-      undef  $_sendto_fhs{$_p};
-      delete $_sendto_fhs{$_p};
-   }
+   _sendto_fhs_close();
 
    ## Close MCE STDOUT/STDERR handles.
 
@@ -929,3 +1011,32 @@ sub _output_loop {
 
 1;
 
+__END__
+
+###############################################################################
+## ----------------------------------------------------------------------------
+## Module usage.
+##
+###############################################################################
+
+=head1 NAME
+
+MCE::Core::Manager - Core methods for the manager process
+
+=head1 VERSION
+
+This document describes MCE::Core::Manager version 1.868
+
+=head1 DESCRIPTION
+
+This package provides the loop and relevant methods used internally by the
+manager process.
+
+There is no public API.
+
+=head1 AUTHOR
+
+Mario E. Roy, S<E<lt>marioeroy AT gmail DOT comE<gt>>
+
+=cut
+
