@@ -11,16 +11,15 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized once );
 
-our $VERSION = '1.843';
+our $VERSION = '1.868';
 
 use base 'MCE::Mutex::Channel';
 use MCE::Util ();
 
-my $has_threads = $INC{'threads.pm'} ? 1 : 0;
-my $tid = $has_threads ? threads->tid()  : 0;
+my $tid = $INC{'threads.pm'} ? threads->tid() : 0;
 
 sub CLONE {
-    $tid = threads->tid() if $has_threads;
+    $tid = threads->tid() if $INC{'threads.pm'};
 }
 
 ###############################################################################
@@ -31,9 +30,9 @@ sub CLONE {
 
 sub new {
     my ($class, %obj) = (@_, impl => 'Channel2');
-    $obj{'_init_pid'} = $has_threads ? $$ .'.'. $tid : $$;
+    $obj{'_init_pid'} = $tid ? $$ .'.'. $tid : $$;
 
-    MCE::Util::_sock_pair(\%obj, qw(_r_sock _w_sock));
+    MCE::Util::_sock_pair(\%obj, qw(_r_sock _w_sock), undef, 1);
 
     syswrite $obj{_r_sock}, '0';
     syswrite $obj{_w_sock}, '0';
@@ -41,14 +40,14 @@ sub new {
     bless \%obj, $class;
 
     if ( caller !~ /^MCE:?/ || caller(1) !~ /^MCE:?/ ) {
-        MCE::Mutex::Channel::_save_for_global_destruction(\%obj);
+        MCE::Mutex::Channel::_save_for_global_cleanup(\%obj);
     }
 
     return \%obj;
 }
 
 sub lock2 {
-    my ($pid, $obj) = ($has_threads ? $$ .'.'. $tid : $$, @_);
+    my ($pid, $obj) = ($tid ? $$ .'.'. $tid : $$, shift);
 
     MCE::Util::_sysread($obj->{_w_sock}, my($b), 1), $obj->{ $pid.'b' } = 1
         unless $obj->{ $pid.'b' };
@@ -60,29 +59,29 @@ sub lock2 {
 *lock_shared2    = \&lock2;
 
 sub unlock2 {
-    my ($pid, $obj) = ($has_threads ? $$ .'.'. $tid : $$, @_);
+    my ($pid, $obj) = ($tid ? $$ .'.'. $tid : $$, shift);
 
-    syswrite($obj->{_r_sock}, '0'), $obj->{ $pid.'b' } = 0
+    CORE::syswrite($obj->{_r_sock}, '0'), $obj->{ $pid.'b' } = 0
         if $obj->{ $pid.'b' };
 
     return;
 }
 
 sub synchronize2 {
-    my ($pid, $obj, $code, @ret) = (
-        $has_threads ? $$ .'.'. $tid : $$, shift, shift
-    );
+    my ($pid, $obj, $code) = ($tid ? $$ .'.'. $tid : $$, shift, shift);
+    my (@ret, $b);
+
     return unless ref($code) eq 'CODE';
 
     # lock, run, unlock - inlined for performance
-    MCE::Util::_sysread($obj->{_w_sock}, my($b), 1), $obj->{ $pid.'b' } = 1
+    MCE::Util::_sysread($obj->{_w_sock}, $b, 1), $obj->{ $pid.'b' } = 1
         unless $obj->{ $pid.'b' };
 
     (defined wantarray)
       ? @ret = wantarray ? $code->(@_) : scalar $code->(@_)
       : $code->(@_);
 
-    syswrite($obj->{_r_sock}, '0'), $obj->{ $pid.'b' } = 0;
+    CORE::syswrite($obj->{_r_sock}, '0'), $obj->{ $pid.'b' } = 0;
 
     return wantarray ? @ret : $ret[-1];
 }
@@ -117,26 +116,42 @@ MCE::Mutex::Channel2 - Provides two mutexes using a single channel
 
 =head1 VERSION
 
-This document describes MCE::Mutex::Channel2 version 1.843
+This document describes MCE::Mutex::Channel2 version 1.868
 
 =head1 DESCRIPTION
 
-A socket implementation based on L<MCE::Mutex>. The secondary lock is accessed
-by calling methods, described in L<MCE::Mutex>, with the C<2> suffix.
+A socket implementation based on C<MCE::Mutex>. The secondary lock is accessed
+by calling methods with the C<2> suffix.
+
+The API is described in L<MCE::Mutex>.
+
+=head2 construction
+
+=over 3
+
+=item new
 
  my $mutex = MCE::Mutex->new( impl => 'Channel2' );
 
+=back
+
 =head2 primary lock
 
 =over 3
 
-=item * $mutex->lock
+=item lock
 
-=item * $mutex->unlock
+=item lock_exclusive
 
-=item * $mutex->synchronize
+=item lock_shared
 
-=item * $mutex->timedwait
+=item unlock
+
+=item synchronize
+
+=item enter
+
+=item timedwait
 
 =back
 
@@ -144,13 +159,19 @@ by calling methods, described in L<MCE::Mutex>, with the C<2> suffix.
 
 =over 3
 
-=item * $mutex->lock2
+=item lock2
 
-=item * $mutex->unlock2
+=item lock_exclusive2
 
-=item * $mutex->synchronize2
+=item lock_shared2
 
-=item * $mutex->timedwait2
+=item unlock2
+
+=item synchronize2
+
+=item enter2
+
+=item timedwait2
 
 =back
 
